@@ -18,3 +18,6 @@ class VulnerabilityManagement:
     branch_tag: str
     commit_hash: str
     environment: str
+    vm_product_type_name: str
+    vm_product_name: str
+    vm_product_description: str
